# streamlit-webrtc

![PyPI](https://img.shields.io/pypi/v/streamlit-webrtc)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/streamlit-webrtc)
![PyPI - License](https://img.shields.io/pypi/l/streamlit-webrtc)
![PyPI - Downloads](https://img.shields.io/pypi/dm/streamlit-webrtc)

[![GitHub Sponsors](https://img.shields.io/github/sponsors/whitphx?label=Sponsor%20me%20on%20GitHub%20Sponsors&style=social)](https://github.com/sponsors/whitphx)

<a href="https://www.buymeacoffee.com/whitphx" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Buy Me A Coffee" width="180" height="50" ></a>

## Example
You can try out the sample app using the following commands.
```
$ pip install streamlit-webrtc opencv-python
$ streamlit run https://raw.githubusercontent.com/whitphx/streamlit-webrtc-example/main/app.py
```

You can also try it out here: https://streamlit-webrtc-example.herokuapp.com/; however, it’s running on a very small Heroku instance on a free plan, and may not work well if multiple users access it at the same time.

The deployment of the above example app is managed in this repository: https://github.com/whitphx/streamlit-webrtc-example/.
